@@ -1,31 +1,17 @@
-/* Copyright 2010  Anton Kreuzkamp <akreuzkamp@web.de>
- * Copyright 2020  Alexander Lohnau <alexander.lohnau@gmx.de>
+/* SPDX-FileCopyrightText: 2010 Anton Kreuzkamp <akreuzkamp@web.de>
+ * SPDX-FileCopyrightText: 2020 Alexander Lohnau <alexander.lohnau@gmx.de>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) version 3, or any
- * later version accepted by the membership of KDE e.V. (or its
- * successor approved by the membership of KDE e.V.), which shall
- * act as a proxy defined in Section 6 of version 3 of the license.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library.  If not, see <http://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
  */
 
 #include "charrunner_config.h"
 #include "config_keys.h"
 
 // KF
+#include <KLocalizedString>
+#include <KMessageWidget>
 #include <KRunner/AbstractRunner>
 #include <KSharedConfig>
-#include <KMessageWidget>
-#include <KLocalizedString>
 
 CharacterRunnerConfigForm::CharacterRunnerConfigForm(QWidget *parent)
     : QWidget(parent)
@@ -69,8 +55,9 @@ void CharacterRunnerConfig::load()
             m_ui->list->addTopLevelItem(item);
         }
     } else {
-        const auto msg = new KMessageWidget(i18nc("Message that config is corrupted",
-            "Config entries for alias list and code list have different sizes, ignoring all."), this);
+        const auto msg = new KMessageWidget(i18nc("Message that config is corrupted", //
+                                                  "Config entries for alias list and code list have different sizes, ignoring all."),
+                                            this);
         m_ui->verticalLayout->insertWidget(0, msg);
     }
 }
@@ -82,8 +69,7 @@ void CharacterRunnerConfig::save()
     KSharedConfig::Ptr cfg = KSharedConfig::openConfig(QStringLiteral("krunnerrc"));
     KConfigGroup grp = cfg->group("Runners").group("CharacterRunner");
 
-    grp.writeEntry(CONFIG_TRIGGERWORD, m_ui->edit_trigger->text().isEmpty()
-                                       ? DEFAULT_TRIGGERWORD.toString() : m_ui->edit_trigger->text());
+    grp.writeEntry(CONFIG_TRIGGERWORD, m_ui->edit_trigger->text().isEmpty() ? DEFAULT_TRIGGERWORD.toString() : m_ui->edit_trigger->text());
 
     QList<QString> aliasList;
     QList<QString> codeList;
@@ -103,7 +89,7 @@ void CharacterRunnerConfig::defaults()
     m_ui->edit_trigger->setText(DEFAULT_TRIGGERWORD.toString());
     m_ui->list->clear();
 
-    emit markAsChanged();
+    markAsChanged();
 }
 
 void CharacterRunnerConfig::addItem()
@@ -131,7 +117,6 @@ void CharacterRunnerConfig::validateDeleteButton()
     m_ui->deleteItem->setDisabled(!m_ui->list->selectedItems().count());
 }
 
-K_PLUGIN_FACTORY(CharacterRunnerConfigFactory,
-                 registerPlugin<CharacterRunnerConfig>(QStringLiteral("kcm_krunner_charrunner"));)
+K_PLUGIN_FACTORY(CharacterRunnerConfigFactory, registerPlugin<CharacterRunnerConfig>(QStringLiteral("kcm_krunner_charrunner"));)
 
 #include "charrunner_config.moc"
