@@ -1,22 +1,9 @@
 /*
- *   Copyright 2008 Sebastian Kügler <sebas@kde.org>
- *   Copyright 2017 Kai Uwe Broulik <kde@privat.broulik.de>
- *   Copyright 2020  Alexander Lohnau <alexander.lohnau@gmx.de>
+ *   SPDX-FileCopyrightText: 2008 Sebastian Kügler <sebas@kde.org>
+ *   SPDX-FileCopyrightText: 2017 Kai Uwe Broulik <kde@privat.broulik.de>
+ *   SPDX-FileCopyrightText: 2020 Alexander Lohnau <alexander.lohnau@gmx.de>
  *
- *   This program is free software; you can redistribute it and/or modify
- *   it under the terms of the GNU Library General Public License as
- *   published by the Free Software Foundation; either version 2, or
- *   (at your option) any later version.
- *
- *   This program is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU General Public License for more details
- *
- *   You should have received a copy of the GNU Library General Public
- *   License along with this program; if not, write to the
- *   Free Software Foundation, Inc.,
- *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+ *   SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
 #include "katesessions.h"
@@ -34,20 +21,15 @@
 
 K_EXPORT_PLASMA_RUNNER_WITH_JSON(KateSessions, "plasma-runner-katesessions.json")
 
-KateSessions::KateSessions(QObject *parent, const QVariantList &args)
-    : Plasma::AbstractRunner(parent, args)
+KateSessions::KateSessions(QObject *parent, const KPluginMetaData &metaData, const QVariantList &args)
+    : Plasma::AbstractRunner(parent, metaData, args)
 {
     setObjectName(QStringLiteral("Kate Sessions"));
-    setIgnoredTypes(Plasma::RunnerContext::File | Plasma::RunnerContext::Directory
-                        | Plasma::RunnerContext::NetworkLocation);
 
-    Plasma::RunnerSyntax s(QStringLiteral("kate :q:"), i18n("Finds Kate sessions matching :q:."));
-    addSyntax(s);
-    setDefaultSyntax(Plasma::RunnerSyntax(QStringLiteral("kate"),
-                                          i18n("Lists all the Kate editor sessions in your account.")));
+    addSyntax(Plasma::RunnerSyntax(QStringLiteral("kate :q:"), i18n("Finds Kate sessions matching :q:.")));
+    addSyntax(Plasma::RunnerSyntax(QStringLiteral("kate"), i18n("Lists all the Kate editor sessions in your account.")));
 
-    m_sessionsFolderPath = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation)
-                            + QStringLiteral("/kate/sessions");
+    m_sessionsFolderPath = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QStringLiteral("/kate/sessions");
 
     // Initialize watchers and sessions
     m_sessionWatch = new KDirWatch(this);
@@ -56,6 +38,7 @@ KateSessions::KateSessions(QObject *parent, const QVariantList &args)
     connect(m_sessionWatch, &KDirWatch::created, this, &KateSessions::loadSessions);
     connect(m_sessionWatch, &KDirWatch::deleted, this, &KateSessions::loadSessions);
     loadSessions();
+    setTriggerWords({m_triggerWord});
 }
 
 KateSessions::~KateSessions()
@@ -73,20 +56,12 @@ void KateSessions::loadSessions()
     }
 
     m_sessions = sessions;
+    suspendMatching(m_sessions.isEmpty());
 }
 
 void KateSessions::match(Plasma::RunnerContext &context)
 {
     QString term = context.query();
-    if (term.length() < 3 || m_sessions.isEmpty() || !context.isValid()) {
-        return;
-    }
-    // Kate writes sessions as desktop actions in the local .desktop file =>
-    // they are already available from the "Applications" Runner and in the normal launcher
-    if (!term.startsWith(m_triggerWord, Qt::CaseInsensitive)) {
-        return;
-    }
-
     bool listAll = false;
     if (term.trimmed().compare(m_triggerWord, Qt::CaseInsensitive) == 0) {
         listAll = true;
@@ -98,7 +73,7 @@ void KateSessions::match(Plasma::RunnerContext &context)
         return;
     }
 
-    for (const QString &session: qAsConst(m_sessions)) {
+    for (const QString &session : qAsConst(m_sessions)) {
         if (listAll || session.contains(term, Qt::CaseInsensitive)) {
             Plasma::QueryMatch match(this);
             match.setType(Plasma::QueryMatch::ExactMatch);
@@ -116,9 +91,7 @@ void KateSessions::run(const Plasma::RunnerContext &context, const Plasma::Query
 {
     Q_UNUSED(context)
 
-    auto *job = new KIO::CommandLauncherJob(QStringLiteral("kate"), {
-        QStringLiteral("--start"), match.data().toString(), QStringLiteral("-n")
-    });
+    auto *job = new KIO::CommandLauncherJob(QStringLiteral("kate"), {QStringLiteral("--start"), match.data().toString(), QStringLiteral("-n")});
     job->setDesktopName(QStringLiteral("org.kde.kate"));
 
     auto *delegate = new KNotificationJobUiDelegate;
